#### import the simple module from the paraview
from paraview.simple import *
#### disable automatic camera reset on 'Show'
paraview.simple._DisableFirstRenderCameraReset()

# create a new 'PVFoamReader'
aOpenFOAM = PVFoamReader(FileName='a.OpenFOAM')
aOpenFOAM.UiRefresh = 0
aOpenFOAM.UseVTKPolyhedron = 0
aOpenFOAM.MeshParts = ['internalMesh']
aOpenFOAM.VolumeFields = ['p', 'U']
aOpenFOAM.LagrangianFields = []
aOpenFOAM.PointFields = []

# get active source.
aOpenFOAM = GetActiveSource()

# get active view
renderView1 = GetActiveViewOrCreate('RenderView')
# uncomment following to set a specific view size
renderView1.ViewSize = [1071, 674]

# get display properties
aOpenFOAMDisplay = GetDisplayProperties(aOpenFOAM, view=renderView1)

# trace defaults for the display properties.
aOpenFOAMDisplay.ColorArrayName = [None, '']

# turn off scalar coloring
ColorBy(aOpenFOAMDisplay, None)

# get animation scene
animationScene1 = GetAnimationScene()

animationScene1.GoToLast()

# set scalar coloring
ColorBy(aOpenFOAMDisplay, ('POINTS', 'p'))

# rescale color and/or opacity maps used to include current data range
aOpenFOAMDisplay.RescaleTransferFunctionToDataRange(True)

# show color bar/color legend
aOpenFOAMDisplay.SetScalarBarVisibility(renderView1, True)

# get color transfer function/color map for 'p'
pLUT = GetColorTransferFunction('p')
pLUT.LockDataRange = 0
pLUT.InterpretValuesAsCategories = 0
pLUT.ShowCategoricalColorsinDataRangeOnly = 0
pLUT.RescaleOnVisibilityChange = 0
pLUT.EnableOpacityMapping = 0
pLUT.RGBPoints = [-4.366660118103027, 0.231373, 0.298039, 0.752941, 0.24093985557556152, 0.865003, 0.865003, 0.865003, 4.84853982925415, 0.705882, 0.0156863, 0.14902]
pLUT.UseLogScale = 0
pLUT.ColorSpace = 'Diverging'
pLUT.UseBelowRangeColor = 0
pLUT.BelowRangeColor = [0.0, 0.0, 0.0]
pLUT.UseAboveRangeColor = 0
pLUT.AboveRangeColor = [1.0, 1.0, 1.0]
pLUT.NanColor = [1.0, 1.0, 0.0]
pLUT.Discretize = 1
pLUT.NumberOfTableValues = 256
pLUT.ScalarRangeInitialized = 1.0
pLUT.HSVWrap = 0
pLUT.VectorComponent = 0
pLUT.VectorMode = 'Magnitude'
pLUT.AllowDuplicateScalars = 1
pLUT.Annotations = []
pLUT.ActiveAnnotatedValues = []
pLUT.IndexedColors = []

# get opacity transfer function/opacity map for 'p'
pPWF = GetOpacityTransferFunction('p')
pPWF.Points = [-4.366660118103027, 0.0, 0.5, 0.0, 4.84853982925415, 1.0, 0.5, 0.0]
pPWF.AllowDuplicateScalars = 1
pPWF.ScalarRangeInitialized = 1

# Apply a preset using its name. Note this may not work as expected when presets have duplicate names.
pLUT.ApplyPreset('Blue to Red Rainbow', True)

#### saving camera placements for all active views

# current camera placement for renderView1
renderView1.CameraPosition = [0.05000000074505806, 0.05000000074505806, 0.27888724573938806]
renderView1.CameraFocalPoint = [0.05000000074505806, 0.05000000074505806, 0.004999999888241291]
renderView1.CameraParallelScale = 0.07088723543695315

#### uncomment the following to render all views
# RenderAllViews()
# alternatively, if you want to write images, you can use SaveScreenshot(...).
